==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/vi/admin/hardware/form.php <==
<?php

return array(
	'bulk_delete'		=> 'Xác nhận Hàng loạt Xóa Tài sản',
  'bulk_delete_help'	=> 'Xem lại tài sản để xóa hàng loạt dưới đây. Sau khi đã xóa, những nội dung này có thể được khôi phục, nhưng chúng sẽ không còn được kết hợp với bất kỳ người dùng nào hiện đang được chỉ định.',
  'bulk_delete_warn'	=> 'Bạn sắp xóa: asset_count tài sản.',
	'bulk_update'		=> 'Cập nhật tài sản số lượng lớn',
	'bulk_update_help'	=> 'Form này cho phép bạn cập nhật nhiều tài sản cùng lúc. Chỉ điền vào ô bạn cần thay đổi. Bất kỳ ô nào để trống sẽ thông báo là chưa thay đổi. ',
	'bulk_update_warn'	=> 'Bạn muốn chỉnh sửa các thuộc tính của :asset_count assets.',
    'checkedout_to'		=> 'Checkout đến',
    'checkout_date'		=> 'Ngày Checkout',
    'checkin_date'		=> 'Ngày Checkin',
    'checkout_to'		=> 'Checkout đến',
    'cost'				=> 'Chi phí mua hàng',
    'create'			=> 'Tạo tài sản',
    'date'				=> 'Ngày mua',
    'depreciation'	    => 'Khấu hao',
    'depreciates_on'	=> 'Trích khấu hao',
    'default_location'	=> 'Vị trí mặc định',
    'eol_date'			=> 'Ngày EOL',
    'eol_rate'			=> 'Tỷ lệ EOL',
    'expected_checkin'  => 'Ngày mong muốn Checkin',
    'expires'			=> 'Hết hạn',
    'fully_depreciated'	=> 'Khấu hao hết',
    'help_checkout'		=> 'Nếu bạn muốn cấp phát tài sản này ngay lập tức, lựa chọn "Sẵn sàng để cấp phát" từ danh sách tình trạng bên trên. ',
    'mac_address'		=> 'Địa chỉ MAC',
    'manufacturer'		=> 'Nhà sản xuất',
    'model'				=> 'Kiểu tài sản',
    'months'			=> 'tháng',
    'name'				=> 'Tên tài sản',
    'notes'				=> 'Ghi chú',
    'order'				=> 'Số đơn hàng',
    'qr'				=> 'Mã QR',
    'requestable'		=> 'Những người dùng có thể yêu cầu tài sản này',
    'select_statustype'	=> 'Lựa chọn loại tình trạng',
    'serial'			=> 'Số Sê-ri',
    'status'			=> 'Tình trạng',
    'tag'				=> 'Thẻ tài sản',
    'update'			=> 'Cập nhật tài sản',
    'warranty'			=> 'Bảo hành',
		'warranty_expires'		=> 'Hết hạn bảo hành',
    'years'				=> 'năm',
)
;

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/vi/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Xác nhận Hàng loạt Xóa Tài sản',
  'bulk_delete_help'	=> 'Xem lại tài sản để xóa hàng loạt dưới đây. Sau khi đã xóa, những nội dung này có thể được khôi phục, nhưng chúng sẽ không còn được kết hợp với bất kỳ người dùng nào hiện đang được chỉ định.',
  'bulk_delete_warn'	=> 'Bạn sắp xóa: asset_count tài sản.',
    'bulk_update'		=> 'Cập nhật tài sản số lượng lớn',
    'bulk_update_help'	=> 'Form này cho phép bạn cập nhật nhiều tài sản cùng lúc. Chỉ điền vào ô bạn cần thay đổi. Bất kỳ ô nào để trống sẽ thông báo là chưa thay đổi. ',
    'bulk_update_warn'	=> 'Bạn muốn chỉnh sửa các thuộc tính của :asset_count assets.',
    'checkedout_to'		=> 'Checkout đến',
    'checkout_date'		=> 'Ngày Checkout',
    'checkin_date'		=> 'Ngày Checkin',
    'checkout_to'		=> 'Checkout đến',
    'cost'				=> 'Chi phí mua hàng',
    'create'			=> 'Tạo tài sản',
    'date'				=> 'Ngày mua',
    'depreciation'	    => 'Khấu hao',
    'depreciates_on'	=> 'Trích khấu hao',
    'default_location'	=> 'Vị trí mặc định',
    'eol_date'			=> 'Ngày EOL',
    'eol_rate'			=> 'Tỷ lệ EOL',
    'expected_checkin'  => 'Ngày mong muốn Checkin',
    'expires'			=> 'Hết hạn',
    'fully_depreciated'	=> 'Khấu hao hết',
    'help_checkout'		=> 'Nếu bạn muốn cấp phát tài sản này ngay lập tức, lựa chọn "Sẵn sàng để cấp phát" từ danh sách tình trạng bên trên. ',
    'mac_address'		=> 'Địa chỉ MAC',
    'manufacturer'		=> 'Nhà sản xuất',
    'model'				=> 'Kiểu tài sản',
    'months'			=> 'tháng',
    'name'				=> 'Tên tài sản',
    'notes'				=> 'Ghi chú',
    'order'				=> 'Số đơn hàng',
    'qr'				=> 'Mã QR',
    'requestable'		=> 'Những người dùng có thể yêu cầu tài sản này',
    'select_statustype'	=> 'Lựa chọn loại tình trạng',
    'serial'			=> 'Số Sê-ri',
    'status'			=> 'Tình trạng',
    'tag'				=> 'Thẻ tài sản',
    'update'			=> 'Cập nhật tài sản',
    'warranty'			=> 'Bảo hành',
        'warranty_expires'		=> 'Hết hạn bảo hành',
    'years'				=> 'năm',
    'asset_location' => 'Update Asset Location',
    'asset_location_update_default_current' => 'Update default location AND actual location',
    'asset_location_update_default' => 'Update only default location',
    'asset_not_deployable' => 'That asset status is not deployable. This asset cannot be checked out.',
    'asset_deployable' => 'That status is deployable. This asset can be checked out.',
    'processing_spinner' => 'Processing...',
];
